@@ -50,13 +50,13 @@ KNewsTicker::KNewsTicker(const TQString &cfgFile, Type t, int actions, TQWidget
 	TQHBoxLayout *layout = new TQHBoxLayout(this);
 
 	m_contextMenu = new KNewsTickerMenu(this);
-	connect(m_contextMenu, TQT_SIGNAL(aboutToHide()),
-			TQT_SLOT(slotContextMenuAboutToHide()));
+	connect(m_contextMenu, TQ_SIGNAL(aboutToHide()),
+			TQ_SLOT(slotContextMenuAboutToHide()));
 	setCustomMenu(m_contextMenu);
 
 	m_arrowButton = new KArrowButton(this);
 	TQToolTip::add(m_arrowButton, i18n("Show menu"));
-	connect(m_arrowButton, TQT_SIGNAL(clicked()), TQT_SLOT(slotArrowButtonPressed()));
+	connect(m_arrowButton, TQ_SIGNAL(clicked()), TQ_SLOT(slotArrowButtonPressed()));
 	m_arrowButton->setFocusPolicy(TQWidget::NoFocus);
 	setupArrowButton();
 	layout->addWidget(m_arrowButton);
@@ -67,11 +67,11 @@ KNewsTicker::KNewsTicker(const TQString &cfgFile, Type t, int actions, TQWidget
 	m_dcopClient->registerAs("knewsticker", false);
 
 	TQToolTip::add(m_scroller, TQString());
-	connect(m_scroller, TQT_SIGNAL(contextMenu()), TQT_SLOT(slotOpenContextMenu()));
+	connect(m_scroller, TQ_SIGNAL(contextMenu()), TQ_SLOT(slotOpenContextMenu()));
 
-	connect(m_newsTimer, TQT_SIGNAL(timeout()), TQT_SLOT(slotUpdateNews()));
+	connect(m_newsTimer, TQ_SIGNAL(timeout()), TQ_SLOT(slotUpdateNews()));
 
-	connect(m_updateTimer, TQT_SIGNAL(timeout()), TQT_SLOT(slotNotifyOfFailures()));
+	connect(m_updateTimer, TQ_SIGNAL(timeout()), TQ_SLOT(slotNotifyOfFailures()));
 
 	m_aboutData->addAuthor("Frerich Raabe", I18N_NOOP("Original author"),
 			"raabe@kde.org");
@@ -141,10 +141,10 @@ void KNewsTicker::reparseConfig()
 		if (!ns->data().enabled)
 			continue;
 
-		connect(ns, TQT_SIGNAL(newNewsAvailable(const NewsSourceBase::Ptr &, bool)),
-				TQT_SLOT(slotNewsSourceUpdated(const NewsSourceBase::Ptr &, bool)));
-		connect(ns, TQT_SIGNAL(invalidInput(const NewsSourceBase::Ptr &)),
-				TQT_SLOT(slotNewsSourceFailed(const NewsSourceBase::Ptr &)));
+		connect(ns, TQ_SIGNAL(newNewsAvailable(const NewsSourceBase::Ptr &, bool)),
+				TQ_SLOT(slotNewsSourceUpdated(const NewsSourceBase::Ptr &, bool)));
+		connect(ns, TQ_SIGNAL(invalidInput(const NewsSourceBase::Ptr &)),
+				TQ_SLOT(slotNewsSourceFailed(const NewsSourceBase::Ptr &)));
 		m_newsSources.append(ns);
 	}
 
@@ -224,7 +224,7 @@ void KNewsTicker::slotNewsSourceFailed(const NewsSourceBase::Ptr &ns)
 
 void KNewsTicker::mousePressEvent(TQMouseEvent *e)
 {
-	if (e->button() == Qt::RightButton)
+	if (e->button() == TQt::RightButton)
 		slotOpenContextMenu();
 }
 
@@ -261,7 +261,7 @@ void KNewsTicker::positionChange(Position)
 
 	TQBoxLayout *layout;
 
-	if (orientation() ==Qt::Horizontal)
+	if (orientation() ==TQt::Horizontal)
 		layout = new TQHBoxLayout(this);
 	else
 		layout = new TQVBoxLayout(this);
@@ -387,16 +387,16 @@ void KNewsTicker::setHighlightedColor(const TQColor &highlightedColor)
 
 void KNewsTicker::setupArrowButton()
 {
-	Qt::ArrowType at;
+	TQt::ArrowType at;
 
-	if (orientation() ==Qt::Horizontal) {
+	if (orientation() ==TQt::Horizontal) {
 		m_arrowButton->setFixedWidth(12);
 		m_arrowButton->setMaximumHeight(128);
-		at = (position() == KPanelApplet::pTop ? Qt::DownArrow : Qt::UpArrow);
+		at = (position() == KPanelApplet::pTop ? TQt::DownArrow : TQt::UpArrow);
 	} else {
 		m_arrowButton->setMaximumWidth(128);
 		m_arrowButton->setFixedHeight(12);
-		at = (position() == KPanelApplet::pLeft ? Qt::RightArrow : Qt::LeftArrow);
+		at = (position() == KPanelApplet::pLeft ? TQt::RightArrow : TQt::LeftArrow);
 	}
 	m_arrowButton->setArrowType(at);
 }
@@ -429,7 +429,7 @@ void KNewsTickerMenu::populateMenu()
 		NewsSourceBase::Ptr ns = *nIt;
 
 		TDEPopupMenu *submenu = new TDEPopupMenu;
-		int checkNewsId = submenu->insertItem(lookIcon, i18n("Check News"), TQT_TQOBJECT(this), TQT_SLOT(slotCheckNews(int)), 0, sources.findIndex(ns) + 1000);
+		int checkNewsId = submenu->insertItem(lookIcon, i18n("Check News"), this, TQ_SLOT(slotCheckNews(int)), 0, sources.findIndex(ns) + 1000);
 		setItemParameter(checkNewsId, sources.findIndex(ns));
 
 		submenu->insertSeparator();
@@ -444,9 +444,9 @@ void KNewsTickerMenu::populateMenu()
 				TQString headline = a->headline().replace('&', "&&");
 				int id;
 				if ( a->read() )
-					id = submenu->insertItem(oldArticleIcon, headline, this, TQT_SLOT(slotOpenArticle(int)), 0, articleIdx+2000);
+					id = submenu->insertItem(oldArticleIcon, headline, this, TQ_SLOT(slotOpenArticle(int)), 0, articleIdx+2000);
 				else
-					id = submenu->insertItem(newArticleIcon, headline, this, TQT_SLOT(slotOpenArticle(int)), 0, articleIdx+2000);
+					id = submenu->insertItem(newArticleIcon, headline, this, TQ_SLOT(slotOpenArticle(int)), 0, articleIdx+2000);
 				kdDebug( 5005 ) << "Setting articles index for " << a->headline() << " to " << articleIdx << endl;
 				setItemParameter( id, articleIdx++ );
 			}
@@ -460,8 +460,8 @@ void KNewsTickerMenu::populateMenu()
 	if (!m_parent->m_cfg->newsSources().isEmpty())
 		insertSeparator();
 
-	insertItem(lookIcon, i18n("Check News"), m_parent, TQT_SLOT(slotUpdateNews()));
-	int i = insertItem(i18n("Offline Mode"), this, TQT_SLOT(slotToggleOfflineMode()), 0, 4711 );
+	insertItem(lookIcon, i18n("Check News"), m_parent, TQ_SLOT(slotUpdateNews()));
+	int i = insertItem(i18n("Offline Mode"), this, TQ_SLOT(slotToggleOfflineMode()), 0, 4711 );
 	setItemChecked(i, m_parent->m_cfg->offlineMode());
 
 	if (m_fullMenu) {
@@ -473,10 +473,10 @@ void KNewsTickerMenu::populateMenu()
 
 		insertTitle(logoIcon, i18n("KNewsTicker"), 0, 0);
 
-		insertItem(helpIcon, i18n("Help"), this, TQT_SLOT(slotShowHelp()));
-		insertItem(logoIcon, i18n("About KNewsTicker"), this, TQT_SLOT(slotShowAbout()));
+		insertItem(helpIcon, i18n("Help"), this, TQ_SLOT(slotShowHelp()));
+		insertItem(logoIcon, i18n("About KNewsTicker"), this, TQ_SLOT(slotShowAbout()));
 		insertSeparator();
-		insertItem(confIcon, i18n("Configure KNewsTicker..."), this, TQT_SLOT(slotConfigure()));
+		insertItem(confIcon, i18n("Configure KNewsTicker..."), this, TQ_SLOT(slotConfigure()));
 	}
 }
 
