@@ -53,7 +53,7 @@ typedef TQPtrList<Group> GroupList;
  */
 class KOPETE_EXPORT Contact : public TQObject
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 	TQ_ENUMS( CanCreateFlags )
