@@ -24,7 +24,7 @@ class TQWidget;
 
 class EditAliasDialog : public AliasDialog
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	EditAliasDialog( TQWidget* parent = 0, const char* name = 0 );
@@ -35,5 +35,3 @@ public slots:
 };
 
 #endif
-
-// kate: space-indent off; replace-tabs off; tab-width 4; indent-mode csands;
