@@ -143,10 +143,10 @@ GaduDCCTransaction::setupIncoming( gg_dcc* dccS )
 
 	peer = dccS->uin;
 	
-	connect ( Kopete::TransferManager::transferManager(), TQT_SIGNAL( accepted( Kopete::Transfer *, const TQString & ) ),
-			  this, TQT_SLOT( slotIncomingTransferAccepted ( Kopete::Transfer *, const TQString & ) ) );
-	connect ( Kopete::TransferManager::transferManager(), TQT_SIGNAL( refused( const Kopete::FileTransferInfo & ) ),
-			  this, TQT_SLOT( slotTransferRefused( const Kopete::FileTransferInfo & ) ) );
+	connect ( Kopete::TransferManager::transferManager(), TQ_SIGNAL( accepted( Kopete::Transfer *, const TQString & ) ),
+			  this, TQ_SLOT( slotIncomingTransferAccepted ( Kopete::Transfer *, const TQString & ) ) );
+	connect ( Kopete::TransferManager::transferManager(), TQ_SIGNAL( refused( const Kopete::FileTransferInfo & ) ),
+			  this, TQ_SLOT( slotTransferRefused( const Kopete::FileTransferInfo & ) ) );
 
 	incoming = true;
 	createNotifiers( true );
@@ -195,8 +195,8 @@ GaduDCCTransaction::createNotifiers( bool connect )
 	write_->setEnabled( false );
 
 	if ( connect ) {
-		TQObject::connect( read_, TQT_SIGNAL( activated( int ) ), TQT_SLOT( watcher() ) );
-		TQObject::connect( write_, TQT_SIGNAL( activated( int ) ), TQT_SLOT( watcher() ) );
+		TQObject::connect( read_, TQ_SIGNAL( activated( int ) ), TQ_SLOT( watcher() ) );
+		TQObject::connect( write_, TQ_SIGNAL( activated( int ) ), TQ_SLOT( watcher() ) );
 	}
 }
 
@@ -279,7 +279,7 @@ GaduDCCTransaction::slotIncomingTransferAccepted ( Kopete::Transfer* transfer, c
 		dccSock_->file_fd = localFile_.handle();
 	}
 
-	connect ( transfer, TQT_SIGNAL( result( TDEIO::Job * ) ), this, TQT_SLOT( slotTransferResult() ) );
+	connect ( transfer, TQ_SIGNAL( result( TDEIO::Job * ) ), this, TQ_SLOT( slotTransferResult() ) );
 
 	// reenable notifiers
 	enableNotifiers( dccSock_->check );
