@@ -28,7 +28,7 @@
 */
 class DeleteItemTask : public ModifyContactListTask
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
 	DeleteItemTask(Task* parent);
