@@ -35,7 +35,7 @@ namespace XMPP
 
 class SecureStream : public ByteStream
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	enum Error { ErrTLS = ErrCustom, ErrSASL };
