@@ -109,15 +109,15 @@ namespace KPF
     connect
       (
        WebServerManager::instance(),
-       TQT_SIGNAL(serverCreated(WebServer *)),
-       TQT_SLOT(slotServerCreated(WebServer *))
+       TQ_SIGNAL(serverCreated(WebServer *)),
+       TQ_SLOT(slotServerCreated(WebServer *))
       );
 
     connect
       (
        WebServerManager::instance(),
-       TQT_SIGNAL(serverDisabled(WebServer *)),
-       TQT_SLOT(slotServerDisabled(WebServer *))
+       TQ_SIGNAL(serverDisabled(WebServer *)),
+       TQ_SLOT(slotServerDisabled(WebServer *))
       );
 
     WebServerManager::instance()->loadConfig();
@@ -148,7 +148,7 @@ namespace KPF
     if (0 == serverCount)
       serverCount = 1;
 
-    if (Qt::Vertical == orientation())
+    if (TQt::Vertical == orientation())
       return h / serverCount;
     else
       return h * serverCount;
@@ -162,7 +162,7 @@ namespace KPF
     if (0 == serverCount)
       serverCount = 1;
 
-    if (Qt::Vertical == orientation())
+    if (TQt::Vertical == orientation())
       return w * serverCount;
     else
       return w / serverCount;
@@ -220,7 +220,7 @@ namespace KPF
   }
 
     void
-  Applet::orientationChange(Qt::Orientation)
+  Applet::orientationChange(TQt::Orientation)
   {
     resetLayout();
   }
@@ -248,7 +248,7 @@ namespace KPF
 
     switch (orientation())
     {
-      case Qt::Vertical:
+      case TQt::Vertical:
         {
           uint itemHeight = height() / itemList_.count();
 
@@ -262,7 +262,7 @@ namespace KPF
         }
         break;
 
-      case Qt::Horizontal:
+      case TQt::Horizontal:
         {
           uint itemWidth = width() / itemList_.count();
 
@@ -282,7 +282,7 @@ namespace KPF
     void
   Applet::mousePressEvent(TQMouseEvent * ev)
   {
-    if (Qt::RightButton != ev->button() && Qt::LeftButton != ev->button())
+    if (TQt::RightButton != ev->button() && TQt::LeftButton != ev->button())
       return;
 
     switch (popup_->exec(TQCursor::pos()))
@@ -316,8 +316,8 @@ namespace KPF
       connect
         (
          wizard_,
-         TQT_SIGNAL(dying(ServerWizard *)),
-         TQT_SLOT(slotWizardDying(ServerWizard *))
+         TQ_SIGNAL(dying(ServerWizard *)),
+         TQ_SLOT(slotWizardDying(ServerWizard *))
         );
 
       wizard_->setLocation(location);
@@ -338,8 +338,8 @@ namespace KPF
       connect
         (
          wizard_,
-         TQT_SIGNAL(dying(ServerWizard *)),
-         TQT_SLOT(slotWizardDying(ServerWizard *))
+         TQ_SIGNAL(dying(ServerWizard *)),
+         TQ_SLOT(slotWizardDying(ServerWizard *))
         );
 
       wizard_->show();
@@ -438,15 +438,15 @@ namespace KPF
     connect
       (
        i,
-       TQT_SIGNAL(newServer()),
-       TQT_SLOT(slotNewServer())
+       TQ_SIGNAL(newServer()),
+       TQ_SLOT(slotNewServer())
       );
 
     connect
       (
        i,
-       TQT_SIGNAL(newServerAtLocation(const TQString &)),
-       TQT_SLOT(slotNewServerAtLocation(const TQString &))
+       TQ_SIGNAL(newServerAtLocation(const TQString &)),
+       TQ_SLOT(slotNewServerAtLocation(const TQString &))
       );
 
     itemList_.append(i);
