@@ -9,7 +9,7 @@ class dccManager;
 
 class dccTopLevel : public TDEMainWindow
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
 
